Welcome to ClientVPS Mirrors

Help for package genefindr

Package {genefindr}


Title: Rapid Gene Characterization Using Public Genomic Databases
Version: 1.0.0
Description: A user-friendly interface for characterizing gene function by disease type and tissue site, integrating curated data from publicly available genomic and proteomic databases to support candidate gene prioritization in experimental workflows.
Depends: R (≥ 4.1.0)
License: GPL-3
Encoding: UTF-8
RoxygenNote: 8.0.0
Imports: httr2, gtexr
URL: https://github.com/martincyd/genefindr
BugReports: https://github.com/martincyd/genefindr/issues
Suggests: knitr, rmarkdown, spelling
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-06-02 21:07:59 UTC; cyd
Author: Cydnie Martin [aut, cre]
Maintainer: Cydnie Martin <martincydenise@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-08 18:30:02 UTC

Characterize a gene using public genomic databases

Description

Characterize a gene using public genomic databases

Usage

findr(gene, disease = NULL, site = NULL)

Arguments

gene

Character. Gene symbol (e.g. "TP53")

disease

Character. Disease context (e.g. "alzheimer")

site

Character. Cancer site (e.g. "breast", "lung"). Can be a vector for multi-site comparison.

Value

Invisibly returns a data frame of results

Examples


findr("TP53", site = "breast")


Characterize multiple genes using public genomic databases

Description

Characterize multiple genes using public genomic databases

Usage

findr_multi(genes, disease = NULL, site = NULL, output = "print")

Arguments

genes

Character vector. Gene symbols (e.g. c("TP53", "BRCA1"))

disease

Character. Disease context

site

Character. Cancer site

output

Character. "print" or "table"

Value

Invisibly returns a data frame of results

Examples


findr_multi(c("TP53", "BRCA1"), site = "breast")

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.